import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import { bytesToSize, getFileIcon } from '@ciscospark/react-component-utils';

import { Button, Icon } from '@collab-ui/react';

var styles = {
  'shareItem': 'shareItem--3oFsm',
  'fileIcon': 'fileIcon--13kPh',
  'meta': 'meta--2Uru1',
  'fileInfo': 'fileInfo--2nyTd',
  'fileName': 'fileName--RaF0r',
  'fileProps': 'fileProps--2CSP4',
  'shareActions': 'shareActions--3taq9',
  'shareActionItem': 'shareActionItem--3dTVX',
  'fileType': 'fileType--2jpZQ'
}; // @related-file ./styles.css

const propTypes = {
  file: PropTypes.shape({
    displayName: PropTypes.string,
    fileSize: PropTypes.number,
    mimeType: PropTypes.string,
    objectType: PropTypes.string
  }).isRequired,
  isPending: PropTypes.bool,
  onDownloadClick: PropTypes.func.isRequired
};

const defaultProps = {
  isPending: false
};

function ActivityShareFile(props) {
  const {
    file,
    isPending,
    onDownloadClick
  } = props;

  const {
    displayName,
    fileSize,
    mimeType,
    objectType
  } = file;

  function handleDownloadClick() {
    onDownloadClick(file);
  }

  return React.createElement(
    'div',
    { className: classNames('ciscospark-activity-share-item', styles.shareItem) },
    React.createElement(
      'div',
      { className: classNames('ciscospark-share-file-icon', styles.fileIcon) },
      React.createElement(Icon, { name: `icon-${getFileIcon(mimeType, 32)}` })
    ),
    React.createElement(
      'div',
      { className: classNames('ciscospark-share-meta', styles.meta) },
      React.createElement(
        'div',
        { className: classNames('ciscospark-share-file-info', styles.fileInfo) },
        React.createElement(
          'div',
          { className: classNames('ciscospark-share-name', styles.fileName) },
          displayName
        ),
        React.createElement(
          'div',
          { className: classNames('ciscospark-share-file-props', styles.fileProps) },
          React.createElement(
            'span',
            { className: classNames('ciscospark-share-file-size', styles.fileSize) },
            bytesToSize(fileSize)
          ),
          React.createElement(
            'span',
            { className: classNames('ciscospark-share-file-type', styles.fileType) },
            objectType
          )
        )
      )
    ),
    !isPending && React.createElement(
      'div',
      { className: classNames('ciscospark-share-item-actions', styles.shareActions) },
      React.createElement(
        'div',
        { className: classNames('ciscospark-share-action-item', styles.shareActionItem) },
        React.createElement(
          Button,
          {
            ariaLabel: 'Download',
            style: { backgroundColor: 'black' },
            circle: true,
            onClick: handleDownloadClick,
            size: 32
          },
          React.createElement(Icon, { name: 'icon-arrow-tail-down_12', color: 'white' })
        )
      )
    )
  );
}

ActivityShareFile.propTypes = propTypes;
ActivityShareFile.defaultProps = defaultProps;

export default ActivityShareFile;